@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-persistent
 version: 1.4.0.3
-id: yesod-persistent-1.4.0.3-3edc22929bdc95f8a7aaec30b1c13cd6
-key: yesod_8WOOnvspvvp8deJb9tS6Tj
+id: yesod-persistent-1.4.0.3-ca84b6eb145e15f51b714d496323d807
+key: yesod_5eiPdZomF2R7e8roJwl0qE
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,17 +20,17 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-persistent-1.4.0.3
-hs-libraries: HSyesod-persistent-1.4.0.3-8WOOnvspvvp8deJb9tS6Tj
+hs-libraries: HSyesod-persistent-1.4.0.3-5eiPdZomF2R7e8roJwl0qE
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
-    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
-    persistent-2.2.4-7bfa93ca2781b33384883da4115f96aa
-    persistent-template-2.1.5-843c6c1cb8c608f5d7b0340a1ba98852
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    persistent-2.2.4.1-550ce3a441e5dfee4f5236d6597d598b
+    persistent-template-2.1.6-abb9add555d6012706d07d6768084389
     resource-pool-0.2.3.2-43a43754061092f307f80bb6d2ee434f
-    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
+    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    yesod-core-1.4.19-f58e956f86f9387c891d6fa112ae88e5
+    yesod-core-1.4.19-42832ae56c3d48408d8da65a0e354ab2
 haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
 haddock-html: /usr/share/doc/haskell-yesod-persistent/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
